#[repr(u8)]pub enum Ahbrxbuf2cr0Regionen {
VALUE0 = 0,
VALUE1 = 1,
}Variants
VALUE0 = 0
Disabled. The buffer hit is based on the value of MSTRID only.
VALUE1 = 1
Enabled. The buffer hit is based on the value of MSTRID and the address within AHBBUFREGIONSTARTn and AHBREGIONENDn.
Implementations