#[repr(u8)]pub enum Readaddropt {
VAL0 = 0,
VAL1 = 1,
}Variants
VAL0 = 0
AHB read burst start address alignment is limited when flash memory is accessed in parallel mode or flash is word-addressable.
VAL1 = 1
AHB read burst start address alignment is not limited. FlexSPI fetches more data than the AHB burst requires for address alignment.
Implementations
Sourceimpl Readaddropt
impl Readaddropt